@@ -1,7 +1,7 @@
 package Perinci::Examples::Completion;
 
-our $DATE = '2019-07-06'; # DATE
-our $VERSION = '0.815'; # VERSION
+our $DATE = '2019-07-19'; # DATE
+our $VERSION = '0.816'; # VERSION
 
 use 5.010;
 use strict;
@@ -73,30 +73,41 @@ sub fruits {
 
 $SPEC{animal_choice} = {
     v => 1.1,
-    summary => 'Specify an animal (optional), some examples given in schema (for completion)',
+    summary => 'Specify an animal (optional) and a color (optional), '.
+        'with some examples given in argument spec or schema (for completion)',
     args => {
         animal => {
             schema => ['str*', {
-                'x.examples' => [
-                    'dog',
-                    'bird',
-                    'elephant',
-                ],
-                'x.examples.summaries' => [
-                    'You cannot teach this animal new tricks when it is old',
-                    'Two of this can be killed with one stone',
-                    'It never forgets',
+                'examples' => [
+                    {value=>'dog', summary=>'You cannot teach this animal new tricks when it is old'},
+                    {value=>'bird', summary=>'Two of this can be killed with one stone'},
+                    {value=>'elephant', summary=>'It never forgets'},
                 ],
             }],
             pos => 0,
         },
+        color => {
+            schema => ['str*'],
+            examples => [
+                'black',
+                'blue',
+                {value=>'chartreuse', summary=>'half green, half yellow'},
+                {value=>'cyan', summary=>'half green, half blue'},
+                'green',
+                'grey',
+                {value=>'magenta', summary=>'half red, half blue'},
+                'red',
+                'white',
+                'yellow',
+            ],
+            pos => 0,
+        },
     },
     description => <<'_',
 
-Demonstrates `x.examples` and `x.examples.summaries` Sah schema attributes.
-Unlike the `in` clause, the value of an argument is not restricted to only
-values specified in the `x.examples`. `x.examples` serves to give examples of
-valid values, hint for completion, etc.
+Demonstrates Rinci argument spec `examples` property as well as Sah schema's
+`examples` clause. This property is a source of valid values for the argument
+and can be used for testing, documentation, or completion.
 
 _
 };
@@ -119,7 +130,7 @@ Perinci::Examples::Completion - More completion examples
 
 =head1 VERSION
 
-This document describes version 0.815 of Perinci::Examples::Completion (from Perl distribution Perinci-Examples), released on 2019-07-06.
+This document describes version 0.816 of Perinci::Examples::Completion (from Perl distribution Perinci-Examples), released on 2019-07-19.
 
 =for Pod::Coverage .*
 
@@ -132,12 +143,11 @@ Usage:
 
  animal_choice(%args) -> [status, msg, payload, meta]
 
-Specify an animal (optional), some examples given in schema (for completion).
+Specify an animal (optional) and a color (optional), with some examples given in argument spec or schema (for completion).
 
-Demonstrates C<x.examples> and C<x.examples.summaries> Sah schema attributes.
-Unlike the C<in> clause, the value of an argument is not restricted to only
-values specified in the C<x.examples>. C<x.examples> serves to give examples of
-valid values, hint for completion, etc.
+Demonstrates Rinci argument spec C<examples> property as well as Sah schema's
+C<examples> clause. This property is a source of valid values for the argument
+and can be used for testing, documentation, or completion.
 
 This function is not exported.
 
@@ -147,6 +157,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<animal> => I<str>
 
+=item * B<color> => I<str>
+
 =back
 
 Returns an enveloped result (an array).
